```
Usage: vcd gateway services ipsec-vpn set-log-level [OPTIONS] <gateway name>
                                                    <log level>

Options:
  -h, --help  Show this message and exit.

```
